pub fn scale_slice_in_place<F: Field>(s: F, slice: &mut [F])👎Deprecated:
use par_scale_slice_in_place instead which will replace this method in the future
This function is deprecated. It is currently a wrapper for par_scale_slice_in_place, which
it should be replaced with if parallelization is required.