pub fn scale_slice_in_place_single_core<F: Field>(slice: &mut [F], s: F)Expand description
Scales each element of the slice by s using packing.
Performance
For large slices, use par_scale_slice_in_place.
pub fn scale_slice_in_place_single_core<F: Field>(slice: &mut [F], s: F)Scales each element of the slice by s using packing.
For large slices, use par_scale_slice_in_place.