pub trait SpongePaddingValue: Copy {
const PAD_ZERO: Self;
const PAD_ONE: Self;
}Expand description
Values that can act as sponge lanes for delimiter padding.
This is used by symmetric sponge adapters that need canonical 0 and 1 symbols while
supporting both field/ring-based lanes and u64-based Keccak lanes behind one API.
Required Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".